summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorYe Li <ye.li@nxp.com>2016-04-12 12:24:02 +0800
committerPeng Fan <peng.fan@nxp.com>2016-04-13 11:28:03 +0800
commitca0df9c20a3b0e67bf95a077115cd43ef61df1b6 (patch)
treed68cdf5fdd7225f5c59bf1ef8a0179db6915a524
parent82b3ab2230f77c92a477d2757dd3e21d25d9c845 (diff)
downloadu-boot-imx-ca0df9c20a3b0e67bf95a077115cd43ef61df1b6.zip
u-boot-imx-ca0df9c20a3b0e67bf95a077115cd43ef61df1b6.tar.gz
u-boot-imx-ca0df9c20a3b0e67bf95a077115cd43ef61df1b6.tar.bz2
MLK-12616-5 GPT: Update GPT driver for MX6ULL
The MX6ULL has GPT with supporting OSC clock source, update the driver accordingly. Signed-off-by: Ye Li <ye.li@nxp.com> (cherry picked from commit b2740fd7a0f8d80b416d4de1f57b6542407d23bd)
-rw-r--r--arch/arm/imx-common/timer.c7
1 files changed, 4 insertions, 3 deletions
diff --git a/arch/arm/imx-common/timer.c b/arch/arm/imx-common/timer.c
index a965d17..e9fad86 100644
--- a/arch/arm/imx-common/timer.c
+++ b/arch/arm/imx-common/timer.c
@@ -46,7 +46,7 @@ static inline int gpt_has_clk_source_osc(void)
if (((is_cpu_type(MXC_CPU_MX6Q) || is_cpu_type(MXC_CPU_MX6D)) &&
(soc_rev() > CHIP_REV_1_0)) || is_cpu_type(MXC_CPU_MX6DL) ||
is_cpu_type(MXC_CPU_MX6SOLO) || is_cpu_type(MXC_CPU_MX6SX) ||
- is_cpu_type(MXC_CPU_MX6UL))
+ is_cpu_type(MXC_CPU_MX6UL) || is_cpu_type(MXC_CPU_MX6ULL))
return 1;
return 0;
@@ -91,12 +91,13 @@ int timer_init(void)
if (gpt_has_clk_source_osc()) {
i |= GPTCR_CLKSOURCE_OSC | GPTCR_TEN;
/* For DL/S, SX, UL, set 24Mhz OSC Enable bit and prescaler */
if (is_cpu_type(MXC_CPU_MX6DL) ||
is_cpu_type(MXC_CPU_MX6SOLO) ||
is_cpu_type(MXC_CPU_MX6SX) ||
is_cpu_type(MXC_CPU_MX7D) ||
- is_cpu_type(MXC_CPU_MX6UL)) {
+ is_cpu_type(MXC_CPU_MX6UL) ||
+ is_cpu_type(MXC_CPU_MX6ULL)) {
i |= GPTCR_24MEN;
/* Produce 3Mhz clock */
@@ -91,12 +91,13 @@ int timer_init(void)
if (gpt_has_clk_source_osc()) {
i |= GPTCR_CLKSOURCE_OSC | GPTCR_TEN;
- /* For DL/S, SX, UL, set 24Mhz OSC Enable bit and prescaler */
+ /* For DL/S, SX, UL, ULL set 24Mhz OSC Enable bit and prescaler */
if (is_cpu_type(MXC_CPU_MX6DL) ||
is_cpu_type(MXC_CPU_MX6SOLO) ||